ExternalClient

Struct ExternalClient 

pub struct ExternalClient { /* private fields */ }
An implementation of the EXTERNAL authentication mechanism, as described in RFC 4422. Authorization identity may be left blank to indicate that the client is requesting to act as the identity associated with the

Implementations

Source

impl ExternalClient

pub fn new(identity: String) -> Self