pub struct ExternalClient { /* private fields */ }Expand description
An implementation of the EXTERNAL authentication mechanism, as described in RFC 4422. Authorization identity may be left blank to indicate that the client is requesting to act as the identity associated with the
Implementations